#!/bin/sh

# Usage: readingtimer [ [0|1|reset] anything ]
# Parameters: 0: unload plugin
#             1: load plugin
#             reset: reset reading settings
#             restore: restore previous reading settings
#             anything means any string
# If anything is passed as a second parameter, then java framework is not restarted
# With no parameter current status is showed


EXTENSION=/mnt/us/extensions/readingtimer
TARGET=/opt/amazon/ebook/config/reader_plugins.xml
#TARGET=./x.xml
PLUGINSTRING='Plugin class="com.amazon.ebook.booklet.reader.plugin.timer.ReadingTimerController"'
PREFERENCES=/var/local/java/prefs/reader.pref

#
# Verify if target file and temp file have the
# same number of lines (and if it's > 1)
#
checkresult () {
    local FA=$1
    local FB=$2
    local A=$( wc -l "$FA" | awk '{print $1}' )
    local B=$( wc -l "$FB" | awk '{print $1}' )
    if [ "$A" -eq "$B" ] && [ "$B" -gt 1 ] ; then
    	return 0
    else
    	return 1
    fi
}

# We can't just "sed -i" inplace because the plugin configuration file 
# cannot be unlinked. So we redirect to a temporary file and then 'cat'
# into the target file

TMPFILE=$(mktemp)
EXITCODE=0

case "$1" in
"0"|"off"|"Off"|"n"|"N")
	sed "s|<$PLUGINSTRING */>|<!--$PLUGINSTRING />-->|g" "$TARGET" > $TMPFILE
	if  checkresult $TMPFILE $TARGET  ; then
	  cp $EXTENSION/start.json $EXTENSION/menu.json
      mntroot rw 2> /dev/null > /dev/null
      cat $TMPFILE > $TARGET
      mntroot ro 2> /dev/null > /dev/null
      [ $2 ] || restart framework
    else
      EXITCODE=1
    fi
    ;;
        
"1"|"on"|"On"|"y"|"Y")
	sed "s|<!--$PLUGINSTRING */>-->|<$PLUGINSTRING />|g" "$TARGET" > $TMPFILE
	if  checkresult $TMPFILE $TARGET  ; then
	  cp $EXTENSION/stop.json $EXTENSION/menu.json
      mntroot rw 2> /dev/null > /dev/null
      cat $TMPFILE > $TARGET
      mntroot ro 2> /dev/null > /dev/null
      [ $2 ] || restart framework
    else
      EXITCODE=2
    fi
    ;;
"reset")
    if [ -f "$PREFERENCES" ] ; then
      mntroot rw 2> /dev/null > /dev/null
      cp -f $PREFERENCES $EXTENSION/reader.pref.$(date +'%Y%m%d-%H%M')
      rm -f $PREFERENCES
      mntroot ro 2> /dev/null > /dev/null
      [ $2 ] || restart framework
    fi
    ;;
"restore")
    F=$(ls -1 $EXTENSION/reader.pref.* | tail -1) 2> /dev/null
    if [ -f "$F" ] ; then
      mntroot rw 2> /dev/null > /dev/null
      cp -f $F $PREFERENCES
      rm -f $F
      mntroot ro 2> /dev/null > /dev/null
      [ $2 ] || restart framework
    fi
    ;;
*)
    L=0 ; grep -q "<$PLUGINSTRING */>" $TARGET && L=1
    U=0 ; grep -q "<!--$PLUGINSTRING */>-->" $TARGET && U=1
    [ "$L$U" == "10" ] && echo "1"
    [ "$L$U" == "01" ] && echo "0"
    [ "$L$U" == "00" ] && echo "Plugin not found or unexpected syntax in $TARGET"
    EXITCODE=3
    ;;
esac

rm -f $TMPFILE

exit $EXITCODE
